Welcome to imgroi's documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 1

   Readme <readme>
   installation
   usage
   api
   contributing
   authorshistory

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
